<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>OutputDirectSoundFactory</name>
    <message>
        <location filename="../outputdirectsoundfactory.cpp" line="28"/>
        <source>DirectSound Plugin</source>
        <translation>DirectSound Eklentisi</translation>
    </message>
    <message>
        <location filename="../outputdirectsoundfactory.cpp" line="52"/>
        <source>About DirectSound Output Plugin</source>
        <translation>DirectSound Çıktı Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../outputdirectsoundfactory.cpp" line="53"/>
        <source>Qmmp DirectSound Output Plugin</source>
        <translation>Qmmp DirectSound Çıktı Eklentisi</translation>
    </message>
    <message>
        <location filename="../outputdirectsoundfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
